@@ -1,26 +1,38 @@
 import sys
-import warnings
+import os
+from typing import Generator
 
 import pytest
-from _pytest._code.code import ExceptionInfo
+from pytest import CallInfo, Config, Item, Parser, TestReport
 from _pytest.skipping import xfailed_key
+from _pytest._code.code import (
+    ExceptionChainRepr,
+    ExceptionInfo,
+    ExceptionRepr,
+    ReprFileLocation,
+)
+from pluggy import Result
 
 from . import check_log, check_raises, context_manager, pseudo_traceback
+from .context_manager import CheckContextManager
 
 
 @pytest.hookimpl(hookwrapper=True, trylast=True)
-def pytest_runtest_makereport(item, call):
-    outcome = yield
-    report = outcome.get_result()
+def pytest_runtest_makereport(
+    item: Item, call: CallInfo[None]
+) -> Generator[None, Result[TestReport], None]:
+    outcome: Result[TestReport] = yield
+    report: TestReport = outcome.get_result()
 
     num_failures = check_log._num_failures
     failures = check_log.get_failures()
     check_log.clear_failures()
 
     if failures:
-        if item._store[xfailed_key]:
+        xfailed_value = item._store[xfailed_key]
+        if xfailed_value and not item.config.option.runxfail:
             report.outcome = "skipped"
-            report.wasxfail = item._store[xfailed_key].reason
+            report.wasxfail = xfailed_value.reason
         else:
 
             summary = f"Failed Checks: {num_failures}"
@@ -37,15 +49,41 @@ def pytest_runtest_makereport(item, call):
             report.outcome = "failed"
             try:
                 raise AssertionError(report.longrepr)
-            except AssertionError:
+            except AssertionError as e:
                 excinfo = ExceptionInfo.from_current()
+                if (pytest.version_tuple >= (7,3,0)
+                        and not os.getenv('PYTEST_XDIST_WORKER')):
+                    # Build a summary report with failure reason
+                    # Depends on internals of pytest, which changed in 7.3
+                    # Also, doesn't work with xdist
+                    #
+                    # Example: Before 7.3:
+                    #   =========== short test summary info ===========
+                    #   FAILED test_example_simple.py::test_fail
+                    # Example after 7.3:
+                    #   =========== short test summary info ===========
+                    #   FAILED test_example_simple.py::test_fail - assert 1 == 2
+                    #
+                    e_str = str(e)
+                    e_str = e_str.split('FAILURE: ')[1]  # Remove redundant "Failure: "
+                    reprcrash = ReprFileLocation(item.nodeid, 0, e_str)
+                    # FIXME - the next two lines have broken types
+                    reprtraceback = ExceptionRepr(reprcrash, excinfo)  # type: ignore
+                    chain_repr = ExceptionChainRepr([(reprtraceback, reprcrash, str(e))])  # type: ignore
+                    report.longrepr = chain_repr
+                else:  # pragma: no cover
+                    # coverage is run on latest pytest
+                    # we'll have one test run on an older pytest just to make sure
+                    # it works.
+                    ...
+
             call.excinfo = excinfo
 
 
-def pytest_configure(config):
+def pytest_configure(config: Config) -> None:
     # Add some red to the failure output, if stdout can accommodate it.
     isatty = sys.stdout.isatty()
-    color = config.option.color
+    color = getattr(config.option, "color", None)
     check_log.should_use_color = (isatty and color == "auto") or (color == "yes")
 
     # If -x or --maxfail=1, then stop on the first failed check
@@ -59,36 +97,26 @@ def pytest_configure(config):
     check_log._stop_on_fail = stop_on_fail
 
     # Allow for --tb=no to turn off check's pseudo tbs
-    traceback_style = config.getvalue("tbstyle")
+    traceback_style = config.getoption("tbstyle", default=None)
     pseudo_traceback._traceback_style = traceback_style
+    check_log._showlocals = config.getoption("showlocals", default=None)
 
     # grab options
     check_log._default_max_fail = config.getoption("--check-max-fail")
     check_log._default_max_report = config.getoption("--check-max-report")
     check_log._default_max_tb = config.getoption("--check-max-tb")
-    no_tb = config.getoption("--check-no-tb")
-    if no_tb:
-        warnings.warn(
-            "--check-no-tb is deprecated; use --check-max-tb=0", DeprecationWarning
-        )
-        check_log._default_max_tb = 0
 
 
 # Allow for tests to grab "check" via fixture:
 # def test_a(check):
 #    check.equal(a, b)
 @pytest.fixture(name="check")
-def check_fixture():
+def check_fixture() -> CheckContextManager:
     return context_manager.check
 
 
 # add some options
-def pytest_addoption(parser):
-    parser.addoption(
-        "--check-no-tb",
-        action="store_true",
-        help="turn off pseudo-tracebacks",
-    )
+def pytest_addoption(parser: Parser) -> None:
     parser.addoption(
         "--check-max-report",
         action="store",
